@@ -797,4 +797,4 @@ class CompositeDataSource(BaseDataSource):
             source_i.get(start_i, end_i, refresh_cache=refresh_cache)
             for (start_i, end_i), source_i in zip(pairwise(index_list), sources_list)
         ]
-        return pd.concat(data_list)
+        return pd.concat(data_list).infer_objects()
